@@ -21,27 +21,19 @@
 
 #include "dolphin_generalsettings.h"
 #include "configurepreviewplugindialog.h"
+#include "settings/serviceitemdelegate.h"
+#include "settings/servicemodel.h"
 
-#include <KConfigGroup>
+#include <KIO/PreviewJob>
 #include <KLocalizedString>
 #include <KServiceTypeTrader>
-#include <KService>
 
-#include <settings/serviceitemdelegate.h>
-#include <settings/servicemodel.h>
-
-#include <QCheckBox>
-#include <QGroupBox>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QListView>
 #include <QPainter>
-#include <QScrollBar>
-#include <QShowEvent>
-#include <QSlider>
-#include <QSpinBox>
 #include <QSortFilterProxyModel>
-#include <QVBoxLayout>
+#include <QSpinBox>
 
 // default settings
 namespace {
@@ -51,9 +43,9 @@ namespace {
 PreviewsSettingsPage::PreviewsSettingsPage(QWidget* parent) :
     SettingsPageBase(parent),
     m_initialized(false),
-    m_listView(0),
+    m_listView(nullptr),
     m_enabledPreviewPlugins(),
-    m_remoteFileSizeBox(0)
+    m_remoteFileSizeBox(nullptr)
 {
     QVBoxLayout* topLayout = new QVBoxLayout(this);
 
@@ -172,11 +164,8 @@ void PreviewsSettingsPage::loadPreviewPlugins()
 
 void PreviewsSettingsPage::loadSettings()
 {
-    KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
-    m_enabledPreviewPlugins = globalConfig.readEntry("Plugins", QStringList()
-                                                     << QStringLiteral("directorythumbnail")
-                                                     << QStringLiteral("imagethumbnail")
-                                                     << QStringLiteral("jpegthumbnail"));
+    const KConfigGroup globalConfig(KSharedConfig::openConfig(), QStringLiteral("PreviewSettings"));
+    m_enabledPreviewPlugins = globalConfig.readEntry("Plugins", KIO::PreviewJob::defaultPlugins());
 
     const qulonglong defaultRemotePreview = static_cast<qulonglong>(MaxRemotePreviewSize) * 1024 * 1024;
     const qulonglong maxRemoteByteSize = globalConfig.readEntry("MaximumRemoteSize", defaultRemotePreview);
